@@ -1,5 +1,3 @@
-from typing import List
-
 from pydantic import UUID4
 from sqlalchemy import JSON, Column, ForeignKey
 from sqlalchemy.orm import relationship
@@ -15,7 +13,7 @@ class Grant(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
     __tablename__ = "grants"
     __table_args__ = (UniqueConstraint("user_id", "client_id"),)
 
-    scope: List[str] = Column(JSON, nullable=False, default=list)
+    scope: list[str] = Column(JSON, nullable=False, default=list)
 
     user_id: UUID4 = Column(
         GUID, ForeignKey(User.id, ondelete="CASCADE"), nullable=False
